#ifndef COM_H
#define COM_H

/////////////////////////////////////////////////////////////////////////////
// SCom: unified structure for the most important comport variables. 
// using COMMTIMEOUTS and DCB directly is just as valid, of course

struct SCom
{
	unsigned long BaudRate; // Baudrate (data bits/s)
	char          ByteSize; // usually 8, or 7
	char          Parity;   // 0: none 1: odd 2: even 3: mark 4: space
	char          StopBits; // 0: 1 or 1: 1.5 or 2: 2
	DWORD ReadIntervalTimeout;
	DWORD ReadTotalTimeoutMultiplier;
	DWORD ReadTotalTimeoutConstant;
	DWORD WriteTotalTimeoutMultiplier;
	DWORD WriteTotalTimeoutConstant;
	DWORD SendReceiveDelay; // corresponds to CCom::m_dwSendReceiveDelay (minimal time to switch between sending (RTS on) and receiving (RTS off))
	char  USBConverter;     // corresponds to CCom::m_cManual (non-zero for manual RTS switching)
};
/////////////////////////////////////////////////////////////////////////////
// CCom: handles the serial port

class CCom
{
public:
	char cDuplex;
	char cMessageOut;
	HANDLE hCom;	

	CCom(void);
	~CCom(void);

	char IsOpen(void);

	DWORD Open(char);
	DWORD Close(void);
	DWORD GetDCB(DCB*);
	DWORD SetDCB(DCB*);
	DWORD GetTimeouts(COMMTIMEOUTS*);
	DWORD SetTimeouts(COMMTIMEOUTS*);
	DWORD OverwriteState(SCom*);
	DWORD Write(const char*);
	DWORD Read(char*,unsigned long);

public:
	DWORD m_dwSendReceiveDelay; // minimal time to switch between sending (RTS on) and receiving (RTS off)

	char m_cToggle; // non-zero when the RTS_CONTROL_TOGGLE flag can be used in DCB::fRtsControl
	char m_cManual; // non-zero when neither RTS_CONTROL_TOGGLE nor WaitCommEvent can be used

protected:
	char m_cOpen;   // non-zero when the device is open
}; 

#endif
